// FILENAME:	CTF_Mercurian_Cavern.cs
//
// CREATOR:  	Com. Sentinal [M.I.B.]
//------------------------------------------------------------------------------
// Stealth Detection - Set to true & players with a "/" in front of their
// will be detected when they join or leave the server.

$stealthDetectOnAdd = false;
$stealthDetectOnRemove = true;  //Ancients has none when a player leaves

//------------------------------------------------------------------------------

$missionName = "CTF_Mercurian_Cavern";

$maxFlagCount  = 8;          // no of flags required by a team to end the game
$flagValue     = 5;          // points your team gets for capturing
$carrierValue  = 2;          //  "      "    "    "    " killing carrier
$killPoints    = 1;
$deathPoints   = 1;
$flagTime = 300;

exec("multiplayerStdLib.cs");
exec("CTFstdLib.cs");

function setDefaultMissionOptions()
{
	$server::TeamPlay = true;
	$server::AllowDeathmatch = false;
	$server::AllowTeamPlay = true;	

   // what can the client choose for a team
	$server::AllowTeamRed = false;
	$server::AllowTeamBlue = true;
	$server::AllowTeamYellow = false;
	$server::AllowTeamPurple = true;

   // what can the server admin choose for available teams
   $server::disableTeamRed = true;
   $server::disableTeamBlue = false;
   $server::disableTeamYellow = true;
   $server::disableTeamPurple = false;
}

function onMissionStart()
{
   initGlobalVars();
   mercurySounds();

   // Keep tracks of hercs near a door
   $HercsAtDoor1 = 0;
   $HercsAtDoor2 = 0;
   $HercsAtDoor3 = 0;
   $HercsAtDoor4 = 0;
}

function onMissionLoad()
{
   cdAudioCycle("NewTech", "Gnash", "Watching", "Cloudburst", "Cyberntx"); 
}

function player::onAdd(%player)
{
   if(($stealthDetectOnAdd == true)&&(strAlign(1, left, getname(%player))=="/"))
   {
        say(0,0,"<f4>"@getname(%player)@" joined the game.","alarm2.wav");
        messagebox(%player,"This server is equipped with an anti-stealth detection system. The slash on your name has been detected. All players have been alerted to your presence.");
   }
   say(%player, 0, "Welcome to CTF Mercurian Cavern! You can download this & other missions made by Com. Sentinal [M.I.B.] on the MIB Website at www.starsiegemeninblack.cjb.net.");
   
   //Activate Rock's Admin Pack if its being used
   RocksPlayerOnAdd(%player);
}

function player::onRemove(%player)
{
   if(($stealthDetectOnRemove == true)&&(strAlign(1, left, getname(%player))=="/"))
   {
      say(0,0,"<f4>"@getname(%player)@" left the game.","alarm2.wav");
   }
}

function door1::trigger::onEnter(%trigger, %vehicleId)
{
   if($hercsAtDoor1 == 0)
   {
      playAnimSequence(getObjectId("MissionGroup\\Stuff\\Door1"), 0, true);
   }
   $hercsAtDoor1 = $hercsAtDoor1 + 1;
}

function door1::trigger::onLeave(%trigger, %vehicleId)
{
   $hercsAtDoor1 = $hercsAtDoor1 - 1;
   if($hercsAtDoor1 == 0)
   {
      playAnimSequence(getObjectId("MissionGroup\\Stuff\\Door1"), 0, false);
   }
}

function door2::trigger::onEnter(%trigger, %vehicleId)
{
   if($hercsAtDoor2 == 0)
   {
      playAnimSequence(getObjectId("MissionGroup\\Stuff\\Door2"), 0, true);
   }
   $hercsAtDoor2 = $hercsAtDoor2 + 1;
}

function door2::trigger::onLeave(%trigger, %vehicleId)
{
   $hercsAtDoor2 = $hercsAtDoor2 - 1;
   if($hercsAtDoor2 == 0)
   {
      playAnimSequence(getObjectId("MissionGroup\\Stuff\\Door2"), 0, false);
   }
}

function door3::trigger::onEnter(%trigger, %vehicleId)
{
   if($hercsAtDoor3 == 0)
   {
      playAnimSequence(getObjectId("MissionGroup\\Stuff\\Door3"), 0, true);
   }
   $hercsAtDoor3 = $hercsAtDoor3 + 1;
}

function door3::trigger::onLeave(%trigger, %vehicleId)
{
   $hercsAtDoor3 = $hercsAtDoor3 - 1;
   if($hercsAtDoor3 == 0)
   {
      playAnimSequence(getObjectId("MissionGroup\\Stuff\\Door3"), 0, false);
   }
}

function door4::trigger::onEnter(%trigger, %vehicleId)
{
   if($hercsAtDoor4 == 0)
   {
      playAnimSequence(getObjectId("MissionGroup\\Stuff\\Door4"), 0, true);
   }
   $hercsAtDoor4 = $hercsAtDoor4 + 1;
}

function door4::trigger::onLeave(%trigger, %vehicleId)
{
   $hercsAtDoor4 = $hercsAtDoor4 - 1;
   if($hercsAtDoor4 == 0)
   {
      playAnimSequence(getObjectId("MissionGroup\\Stuff\\Door4"), 0, false);
   }
}

function boundary::trigger::onEnter(%trigger, %vehicleId)
{
   %player = playerManager::vehicleIdToPlayerNum(%vehicleId);
   healObject(%vehicleId, -99999);
   messageBox(%player, "You were killed for going out of bounds.");
}

